import { Snapshots } from "../operationsInterfaces";
import { AppConfigurationManagementClient } from "../appConfigurationManagementClient";
import { SimplePollerLike, OperationState } from "@azure/core-lro";
import { SnapshotsGetOptionalParams, SnapshotsGetResponse, Snapshot, SnapshotsCreateOptionalParams, SnapshotsCreateResponse } from "../models";
/** Class containing Snapshots operations. */
export declare class SnapshotsImpl implements Snapshots {
    private readonly client;
    /**
     * Initialize a new instance of the class Snapshots class.
     * @param client Reference to the service client
     */
    constructor(client: AppConfigurationManagementClient);
    /**
     * Gets the properties of the specified snapshot. NOTE: This operation is intended for use in Azure
     * Resource Manager (ARM) Template deployments. For all other scenarios involving App Configuration
     * snapshots the data plane API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param options The options parameters.
     */
    get(resourceGroupName: string, configStoreName: string, snapshotName: string, options?: SnapshotsGetOptionalParams): Promise<SnapshotsGetResponse>;
    /**
     * Creates a snapshot. NOTE: This operation is intended for use in Azure Resource Manager (ARM)
     * Template deployments. For all other scenarios involving App Configuration snapshots the data plane
     * API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param body The parameters for creating a snapshot.
     * @param options The options parameters.
     */
    beginCreate(resourceGroupName: string, configStoreName: string, snapshotName: string, body: Snapshot, options?: SnapshotsCreateOptionalParams): Promise<SimplePollerLike<OperationState<SnapshotsCreateResponse>, SnapshotsCreateResponse>>;
    /**
     * Creates a snapshot. NOTE: This operation is intended for use in Azure Resource Manager (ARM)
     * Template deployments. For all other scenarios involving App Configuration snapshots the data plane
     * API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param body The parameters for creating a snapshot.
     * @param options The options parameters.
     */
    beginCreateAndWait(resourceGroupName: string, configStoreName: string, snapshotName: string, body: Snapshot, options?: SnapshotsCreateOptionalParams): Promise<SnapshotsCreateResponse>;
}
//# sourceMappingURL=snapshots.d.ts.map