/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __awaiter } from "tslib";
import * as coreClient from "@azure/core-client";
import * as Mappers from "../models/mappers";
import * as Parameters from "../models/parameters";
import { createHttpPoller, } from "@azure/core-lro";
import { createLroSpec } from "../lroImpl";
/** Class containing Snapshots operations. */
export class SnapshotsImpl {
    /**
     * Initialize a new instance of the class Snapshots class.
     * @param client Reference to the service client
     */
    constructor(client) {
        this.client = client;
    }
    /**
     * Gets the properties of the specified snapshot. NOTE: This operation is intended for use in Azure
     * Resource Manager (ARM) Template deployments. For all other scenarios involving App Configuration
     * snapshots the data plane API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param options The options parameters.
     */
    get(resourceGroupName, configStoreName, snapshotName, options) {
        return this.client.sendOperationRequest({ resourceGroupName, configStoreName, snapshotName, options }, getOperationSpec);
    }
    /**
     * Creates a snapshot. NOTE: This operation is intended for use in Azure Resource Manager (ARM)
     * Template deployments. For all other scenarios involving App Configuration snapshots the data plane
     * API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param body The parameters for creating a snapshot.
     * @param options The options parameters.
     */
    beginCreate(resourceGroupName, configStoreName, snapshotName, body, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const directSendOperation = (args, spec) => __awaiter(this, void 0, void 0, function* () {
                return this.client.sendOperationRequest(args, spec);
            });
            const sendOperationFn = (args, spec) => __awaiter(this, void 0, void 0, function* () {
                var _a;
                let currentRawResponse = undefined;
                const providedCallback = (_a = args.options) === null || _a === void 0 ? void 0 : _a.onResponse;
                const callback = (rawResponse, flatResponse) => {
                    currentRawResponse = rawResponse;
                    providedCallback === null || providedCallback === void 0 ? void 0 : providedCallback(rawResponse, flatResponse);
                };
                const updatedArgs = Object.assign(Object.assign({}, args), { options: Object.assign(Object.assign({}, args.options), { onResponse: callback }) });
                const flatResponse = yield directSendOperation(updatedArgs, spec);
                return {
                    flatResponse,
                    rawResponse: {
                        statusCode: currentRawResponse.status,
                        body: currentRawResponse.parsedBody,
                        headers: currentRawResponse.headers.toJSON(),
                    },
                };
            });
            const lro = createLroSpec({
                sendOperationFn,
                args: { resourceGroupName, configStoreName, snapshotName, body, options },
                spec: createOperationSpec,
            });
            const poller = yield createHttpPoller(lro, {
                restoreFrom: options === null || options === void 0 ? void 0 : options.resumeFrom,
                intervalInMs: options === null || options === void 0 ? void 0 : options.updateIntervalInMs,
                resourceLocationConfig: "azure-async-operation",
            });
            yield poller.poll();
            return poller;
        });
    }
    /**
     * Creates a snapshot. NOTE: This operation is intended for use in Azure Resource Manager (ARM)
     * Template deployments. For all other scenarios involving App Configuration snapshots the data plane
     * API should be used instead.
     * @param resourceGroupName The name of the resource group. The name is case insensitive.
     * @param configStoreName The name of the configuration store.
     * @param snapshotName The name of the snapshot.
     * @param body The parameters for creating a snapshot.
     * @param options The options parameters.
     */
    beginCreateAndWait(resourceGroupName, configStoreName, snapshotName, body, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const poller = yield this.beginCreate(resourceGroupName, configStoreName, snapshotName, body, options);
            return poller.pollUntilDone();
        });
    }
}
// Operation Specifications
const serializer = coreClient.createSerializer(Mappers, /* isXml */ false);
const getOperationSpec = {
    path: "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/snapshots/{snapshotName}",
    httpMethod: "GET",
    responses: {
        200: {
            bodyMapper: Mappers.Snapshot,
        },
        default: {
            bodyMapper: Mappers.ErrorResponseAutoGenerated,
        },
    },
    queryParameters: [Parameters.apiVersion],
    urlParameters: [
        Parameters.$host,
        Parameters.subscriptionId,
        Parameters.configStoreName,
        Parameters.resourceGroupName1,
        Parameters.snapshotName,
    ],
    headerParameters: [Parameters.accept],
    serializer,
};
const createOperationSpec = {
    path: "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppConfiguration/configurationStores/{configStoreName}/snapshots/{snapshotName}",
    httpMethod: "PUT",
    responses: {
        200: {
            bodyMapper: Mappers.Snapshot,
        },
        201: {
            bodyMapper: Mappers.Snapshot,
        },
        202: {
            bodyMapper: Mappers.Snapshot,
        },
        204: {
            bodyMapper: Mappers.Snapshot,
        },
        default: {
            bodyMapper: Mappers.ErrorResponseAutoGenerated,
        },
    },
    requestBody: Parameters.body,
    queryParameters: [Parameters.apiVersion],
    urlParameters: [
        Parameters.$host,
        Parameters.subscriptionId,
        Parameters.configStoreName,
        Parameters.resourceGroupName1,
        Parameters.snapshotName,
    ],
    headerParameters: [Parameters.accept, Parameters.contentType],
    mediaType: "json",
    serializer,
};
//# sourceMappingURL=snapshots.js.map