import { PagedAsyncIterableIterator } from "@azure/core-paging";
import { OperationDefinition, OperationsListOptionalParams, CheckNameAvailabilityParameters, OperationsCheckNameAvailabilityOptionalParams, OperationsCheckNameAvailabilityResponse, OperationsRegionalCheckNameAvailabilityOptionalParams, OperationsRegionalCheckNameAvailabilityResponse } from "../models";
/** Interface representing a Operations. */
export interface Operations {
    /**
     * Lists the operations available from this provider.
     * @param options The options parameters.
     */
    list(options?: OperationsListOptionalParams): PagedAsyncIterableIterator<OperationDefinition>;
    /**
     * Checks whether the configuration store name is available for use.
     * @param checkNameAvailabilityParameters The object containing information for the availability
     *                                        request.
     * @param options The options parameters.
     */
    checkNameAvailability(checkNameAvailabilityParameters: CheckNameAvailabilityParameters, options?: OperationsCheckNameAvailabilityOptionalParams): Promise<OperationsCheckNameAvailabilityResponse>;
    /**
     * Checks whether the configuration store name is available for use.
     * @param location The location in which uniqueness will be verified.
     * @param checkNameAvailabilityParameters The object containing information for the availability
     *                                        request.
     * @param options The options parameters.
     */
    regionalCheckNameAvailability(location: string, checkNameAvailabilityParameters: CheckNameAvailabilityParameters, options?: OperationsRegionalCheckNameAvailabilityOptionalParams): Promise<OperationsRegionalCheckNameAvailabilityResponse>;
}
//# sourceMappingURL=operations.d.ts.map