/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
import { __asyncValues, __awaiter } from "tslib";
import { env, Recorder, isPlaybackMode, } from "@azure-tools/test-recorder";
import { createTestCredential } from "@azure-tools/test-credential";
import { assert } from "chai";
import { AppConfigurationManagementClient } from "../src/appConfigurationManagementClient";
const replaceableVariables = {
    SUBSCRIPTION_ID: "88888888-8888-8888-8888-888888888888"
};
const recorderOptions = {
    envSetupForPlayback: replaceableVariables,
    removeCentralSanitizers: [
        "AZSDK3493", // .name in the body is not a secret and is listed below in the beforeEach section
        "AZSDK3430", // .id in the body is not a secret and is listed below in the beforeEach section
    ],
};
export const testPollingOptions = {
    updateIntervalInMs: isPlaybackMode() ? 0 : undefined,
};
describe("AppConfiguration test", () => {
    let recorder;
    let subscriptionId;
    let client;
    let location;
    let resourceGroup;
    let resourcename;
    beforeEach(function () {
        return __awaiter(this, void 0, void 0, function* () {
            recorder = new Recorder(this.currentTest);
            yield recorder.start(recorderOptions);
            subscriptionId = env.SUBSCRIPTION_ID || '';
            // This is an example of how the environment variables are used
            const credential = createTestCredential();
            client = new AppConfigurationManagementClient(credential, subscriptionId, recorder.configureClientOptions({}));
            location = "eastus";
            resourceGroup = "myjstest";
            resourcename = "resourcetest";
        });
    });
    afterEach(function () {
        return __awaiter(this, void 0, void 0, function* () {
            yield recorder.stop();
        });
    });
    it("operations list test", function () {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, e_1, _b, _c;
            const resArray = new Array();
            try {
                for (var _d = true, _e = __asyncValues(client.operations.list()), _f; _f = yield _e.next(), _a = _f.done, !_a; _d = true) {
                    _c = _f.value;
                    _d = false;
                    let item = _c;
                    resArray.push(item);
                }
            }
            catch (e_1_1) { e_1 = { error: e_1_1 }; }
            finally {
                try {
                    if (!_d && !_a && (_b = _e.return)) yield _b.call(_e);
                }
                finally { if (e_1) throw e_1.error; }
            }
            assert.notEqual(resArray.length, 0);
        });
    });
    it("configurationStores create test", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield client.configurationStores.beginCreateAndWait(resourceGroup, resourcename, {
                dataPlaneProxy: {
                    authenticationMode: "Pass-through",
                    privateLinkDelegation: "Enabled",
                },
                location,
                sku: { name: "Standard" },
            }, testPollingOptions);
            assert.equal(res.name, resourcename);
        });
    });
    it("configurationStores get test", function () {
        return __awaiter(this, void 0, void 0, function* () {
            const res = yield client.configurationStores.get(resourceGroup, resourcename);
            assert.equal(res.name, resourcename);
        });
    });
    it("configurationStores list test", function () {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, e_2, _b, _c;
            const resArray = new Array();
            try {
                for (var _d = true, _e = __asyncValues(client.configurationStores.listByResourceGroup(resourceGroup)), _f; _f = yield _e.next(), _a = _f.done, !_a; _d = true) {
                    _c = _f.value;
                    _d = false;
                    let item = _c;
                    resArray.push(item);
                }
            }
            catch (e_2_1) { e_2 = { error: e_2_1 }; }
            finally {
                try {
                    if (!_d && !_a && (_b = _e.return)) yield _b.call(_e);
                }
                finally { if (e_2) throw e_2.error; }
            }
            assert.equal(resArray.length, 1);
        });
    });
    it("configurationStores delete test", function () {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, e_3, _b, _c;
            const resArray = new Array();
            const res = yield client.configurationStores.beginDeleteAndWait(resourceGroup, resourcename);
            try {
                for (var _d = true, _e = __asyncValues(client.configurationStores.listByResourceGroup(resourceGroup)), _f; _f = yield _e.next(), _a = _f.done, !_a; _d = true) {
                    _c = _f.value;
                    _d = false;
                    let item = _c;
                    resArray.push(item);
                }
            }
            catch (e_3_1) { e_3 = { error: e_3_1 }; }
            finally {
                try {
                    if (!_d && !_a && (_b = _e.return)) yield _b.call(_e);
                }
                finally { if (e_3) throw e_3.error; }
            }
            assert.equal(resArray.length, 0);
        });
    });
});
//# sourceMappingURL=appconfiguration_operations_test.spec.js.map